User prompt
Delay game over for 2 seconds in level 1 and 2
User prompt
Only show crash message in level 1 or 2
User prompt
Every 5 levels increase gravity by 10%
User prompt
Asteroids should not spawn on a radius of 500 pixels from where the lander spawns
User prompt
Only show crash message if level is 1 or 2
User prompt
Increase time between crash and game over for 2 second
User prompt
Move crash message 100 pixela higer
User prompt
When lander crashes show a message in white font in the center of thebscreen thatvreads: "Slow down cap! Keep Y speed below 2!"
User prompt
Show crash message in the center of thebscreen
User prompt
When lander crashes into platform show messgae that reads: "Watch your speed cap! Keep it below 2!"
User prompt
On game start fuel txt should say 100% Fuel
User prompt
500 fuel is 100%
User prompt
Set initial fuel to 500
User prompt
As game progresses decrease initial fuel and increase gravity
User prompt
Fuel should read 100% Fuel on game start
User prompt
Reduce initial spawn of asteroids to half
User prompt
Show fuel txt as a percentage
User prompt
Asteroids should start spawning on level 5
User prompt
Double size of level txr
User prompt
Spawn asteroids on elvel 1
User prompt
Move thruster 20 pixela higher
User prompt
Move thruster 30 pixela up
User prompt
Fix Bug: 'Uncaught Error: [object Object]addChildAt: The index 1 supplied is out of bounds 0' in this line: 'var background = game.addChildAt(LK.getAsset('background', 'Game Background', 0, 0), 1);' Line Number: 315
User prompt
Show baclground in front of baclground2
User prompt
Make stars smaller
===================================================================
--- original.js
+++ change.js
@@ -51,9 +51,9 @@
}
// Update thruster position and visibility
thruster.x = self.x;
- thruster.y = self.y + self.height; // Position thruster 20 pixels closer to the lander
+ thruster.y = self.y + self.height - 30; // Position thruster 30 pixels above the lander
thruster.visible = self.isThrusting;
};
self.land = function () {
self.isLanding = true;